@@ -6,11 +6,12 @@ use Carp ();
 use Import::Into ();
 use MooX::Press 0.025 ();
 use MooX::Press::Keywords ();
+use Syntax::Keyword::Try ();
 
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008';
+our $VERSION   = '0.009';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -252,7 +253,7 @@ my $handle_signature_list = sub {
 };
 
 keytype RoleList is /
-	\+?\s*
+	\s*
 	(
 		(?&PerlBlock) | (?&PerlQualifiedIdentifier)
 	)
@@ -286,12 +287,6 @@ my $handle_role_list = sub {
 		my $suffix = '';
 		my $role_params   = undef;
 		
-		if ($rolelist =~ /^\+/xs) {
-			die 'unexpected plus sign' if $kind eq 'role';
-			$prefix = '+';
-			$rolelist =~ s/^\+\s*//xs;
-		}
-		
 		if ($rolelist =~ /^((?&PerlBlock)) $PPR::GRAMMAR/xso) {
 			$role = $1;
 			$role_is_block = 1;
@@ -444,7 +439,9 @@ sub import {
 	# Export utility stuff
 	#
 	MooX::Pression::_Gather->import::into($caller, -gather => %opts);
-	MooX::Press::Keywords->import::into($caller, qw( -booleans -privacy -util -try ));
+	MooX::Press::Keywords->import::into($caller, qw( -booleans -privacy -util ));
+	Syntax::Keyword::Try->import::into($caller);
+	
 	$_->import::into($caller, qw( -types -is -assert ))
 		for qw(Types::Standard Types::Common::Numeric Types::Common::String);
 	
@@ -471,7 +468,7 @@ sub import {
 			$classdfn,
 		);
 	}
-	keyword class ('+'? $plus, QualifiedIdentifier $classname, ';') {
+	keyword class ('+'? $plus, QualifiedIdentifier $classname) {
 		sprintf(
 			'use MooX::Pression::_Gather -gather, %s => {};',
 			B::perlstring("class:$plus$classname"),
@@ -501,13 +498,37 @@ sub import {
 			$classdfn,
 		);
 	}
-	keyword role (QualifiedIdentifier $classname, OWS, ';') {
+	keyword role (QualifiedIdentifier $classname) {
 		sprintf(
 			'use MooX::Pression::_Gather -gather, %s => {};',
 			B::perlstring('role:'.$classname),
 		);
 	}
 	
+	# `toolkit` keyword
+	#
+	keyword toolkit (Identifier $tk, '(', QualifiedIdentifier|Comma @imports, ')') {
+		my @processed_imports;
+		while (@imports) {
+			no warnings 'uninitialized';
+			my $next = shift @imports;
+			if ($next =~ /^::(.+)$/) {
+				push @processed_imports, $1;
+			}
+			elsif ($next =~ /^[^\W0-9]/) {
+				push @processed_imports, sprintf('%sX::%s', $tk, $next);
+			}
+			else {
+				die "Expected package name, got $next";
+			}
+			$imports[0] eq ',' and shift @imports;
+		}
+		sprintf('q[%s]->_toolkit(%s);', $me, join ",", map(B::perlstring($_), $tk, @processed_imports));
+	}
+	keyword toolkit (Identifier $tk) {
+		sprintf('q[%s]->_toolkit(%s);', $me, B::perlstring($tk));
+	}
+	
 	# `begin` and `end` keywords
 	#
 	keyword begin (Block $code) {
@@ -627,7 +648,7 @@ sub import {
 	keyword factory (Identifier|Block $name, 'via', Identifier $via) {
 		$me->_handle_factory_keyword($name, $via, undef, undef);
 	}
-	keyword factory (Identifier|Block $name, ';') {
+	keyword factory (Identifier|Block $name) {
 		$me->_handle_factory_keyword($name, 'new', undef, undef);
 	}
 	
@@ -713,6 +734,12 @@ sub _with {
 	shift;
 	push @{ $OPTS{with}||=[] }, @_;
 }
+sub _toolkit {
+	shift;
+	my ($toolkit, @imports) = @_;
+	$OPTS{toolkit} = $toolkit;
+	push @{ $OPTS{import}||=[] }, @imports if @imports;
+}
 sub _requires {
 	shift;
 	push @{ $OPTS{requires}||=[] }, @_;
@@ -1095,14 +1122,41 @@ Often it makes more sense to parameterize roles than classes.
     }
   }
 
-=head3 C<< type_name >>
+=head3 C<< toolkit >>
 
-  class Homo::Sapiens {
-    type_name Human;
+Use a different toolkit instead of Moo.
+
+  # use Mouse
+  class Foo {
+    toolkit Mouse;
+  }
+  
+  # use Moose
+  # use MooseX::Aliases
+  # use MooseX::StrictConstructor
+  class Bar {
+    toolkit Moose ( Aliases, StrictConstructor );
   }
 
-The class will still be called L<MyApp::Homo::Sapiens> but the type in the
-type library will be called B<Human> instead of B<Homo_Sapiens>.
+You can of course specify you want to use Moo:
+
+  class Baz {
+    toolkit Moo;
+  }
+
+Not all MooseX/MouseX/MooX packages will work, but *X::StrictConstructor will.
+
+It is possible to set a default toolkit when you import MooX::Pression.
+
+  use MooX::Pression (
+    ...,
+    toolkit => 'Moose',
+  );
+
+  use MooX::Pression (
+    ...,
+    toolkit => 'Mouse',
+  );
 
 =head3 C<< extends >>
 
@@ -1289,7 +1343,7 @@ For enumerations, you can define them like this:
   }
 
 MooX::Pression integrates support for L<MooX::Enumeration> (and
-L<MooseX::Enumeration>).
+L<MooseX::Enumeration>, but MouseX::Enumeration doesn't exist).
 
   class Person {
     ...;
@@ -1313,6 +1367,30 @@ Checking C<< $bob->status eq 'alvie' >> is prone to typos, but
 C<< $bob->status_is_alvie >> will cause a runtime error because the
 method is not defined.
 
+MooX::Pression also integrates support for L<Sub::HandlesVia> allowing
+you to delegate certain methods to unblessed references and non-reference
+values. For example:
+
+  class Person {
+    has age (
+      type         => 'Int',
+      default      => 0,
+      handles_via  => 'Counter',
+      handles      => {
+        get_older => 'inc',   # increment age
+      },
+    );
+    method birthday () {
+      $self->get_older;
+      if ($self->age < 30) {
+        say "yay!";
+      }
+      else {
+        say "urgh!";
+      }
+    }
+  }
+
 It is possible to add hints to the attribute name as a shortcut for common
 specifications.
 
@@ -1715,6 +1793,38 @@ Now C<< MyApp->new_man >> will call C<< MyApp::Person->new_guy >>.
 C<< factory new_person >> with no C<via> or method body is basically
 like saying C<< via new >>.
 
+=head4 Implementing a singleton
+
+Factories make it pretty easy to implement a singleton.
+
+  class AppConfig {
+    ...;
+    
+    factory get_appconfig () {
+      state $config = $class->new();
+    }
+  }
+
+Now C<< MyApp->get_appconfig >> will always return the same AppConfig object.
+Because any explicit use of the C<factory> keyword in a class definition
+suppresses the automatic creation of a factory method for the class, there
+will be no C<< MyApp->new_appconfig >> method for creating new objects
+of that class.
+
+(People can still manually call C<< MyApp::AppConfig->new >> to get a new
+AppConfig object, but remember MooX::Pression discourages calling constructors
+directly, and encourages you to use the factory package for instantiating
+objects!)
+
+=head3 C<< type_name >>
+
+  class Homo::Sapiens {
+    type_name Human;
+  }
+
+The class will still be called L<MyApp::Homo::Sapiens> but the type in the
+type library will be called B<Human> instead of B<Homo_Sapiens>.
+
 =head3 C<< coerce >>
 
   class Person {
@@ -1821,31 +1931,12 @@ of C<confess> is super-powered and runs its arguments through C<sprintf>.
     }
   }
 
-And MooX::Pression exports everything from L<Try::Tiny> because it's
-cool. (This might be replaced with another C<try> module in the future?)
+And MooX::Pression exports L<Syntax::Keyword::Try> for you. Useful to have.
 
 And last but not least, it exports all the types, C<< is_* >> functions,
 and C<< assert_* >> functions from L<Types::Standard>,
 L<Types::Common::String>, and L<Types::Common::Numeric>.
 
-=head2 MooseX::Pression or MouseX::Pression?
-
-  use MooX::Pression (
-    ...,
-    toolkit => 'Moose',
-  );
-
-  use MooX::Pression (
-    ...,
-    toolkit => 'Mouse',
-  );
-
-The ability to choose a toolkit on a package-by-package basis is not
-currently supported. (Though it's implemented in MooX::Press.)
-
-The C<< handles => 1 >> and C<< handles => 2 >> features for enum
-attributes are not supported with Mouse.
-
 =head2 MooX::Pression vs Moops
 
 MooX::Pression has fewer dependencies than Moops, and crucially doesn't
@@ -2071,12 +2162,6 @@ MooX::Pression:
     constant PI = 3.2;
   }
 
-=head2 Future Directions
-
-Something like MooX::HandlesVia or Moose native traits would be good.
-MooX::HandlesVia doesn't work well for non-reference values though.
-MooX::Enumeration proves that it's possible to do!
-
 =head1 BUGS
 
 Please report any bugs to
